@@ -94,9 +94,13 @@ class Domoticz(IPlugin):
 #				
 		#		resp = requests.get ('http://192.168.0.3:8080/json.htm?type=command&param=switchlight&idx=%s&switchcmd=%s&level=0' % (rs['idx'],on_off.capitalize()))
 				resp = requests.get ('http://192.168.0.3:8080/json.htm?type=devices&filter=temp&used=true&order=Name')
+				jsonreq = resp.json()
 #				log.msg("resp  :  %s" % (req))				
 				log.msg("resp  :  %s" % (resp))
-				log.msg("response   :  %s" % (resp.json()))		
+				log.msg("response   :  %s" % (jsonreq))
+				for xx in jsonreq.result.length
+					log.msg(" jsonreq - idx   :  %s" % (xx(idx)))
+					log.msg("   jsonreq - type   :  %s" % (xx(Type)))
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
